==> node-etcd3-0.1.0.tgz: package/index.js <==
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator.throw(value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
const grpc = require("grpc");
const deasyncPromise = require("deasync-promise");
const etcdProto = grpc.load(__dirname + "/protos/rpc.proto");
class EtcdError extends Error {
    constructor(message, internal) {
        super(message);
        this.internal = internal;
    }
}
class Etcd {
    constructor(server = "localhost:2379", options = {}) {
        this.credentials = grpc.credentials.createInsecure();
        this.server = server;
        this.options = options;
        this.clients = {
            KV: new etcdProto.etcdserverpb.KV(this.server, this.credentials)
        };
    }
    getBuffer(obj) {
        if (Buffer.isBuffer(obj))
            return obj;
        else if (obj == null)
            return new Buffer(0);
        else if (typeof obj === "string")
            return new Buffer(obj);
        else
            return new Buffer(JSON.stringify(obj));
    }
    callClient(client, method, arg) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                this.clients[client][method](arg, (err, response) => {
                    if (err) {
                        reject(new EtcdError(`etcd ${client}.${method} failed`, err));
                        return;
                    }
                    resolve(response);
                });
            });
        });
    }
    /**
     * blocking version of get()
     * @see {@link get}
     */
    getSync(key) { return deasyncPromise(this.get(key)); }
    /**
     * get a key from etcd
     * @param key - key to get
     * @return value of the key
     */
    get(key) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.callClient("KV", "range", {
                key: this.getBuffer(key)
            }).then((res) => {
                if (res.kvs.length) {
                    return res.kvs[0].value.toString();
                }
                else {
                    // key not found
                    return null;
                }
            });
        });
    }
    /**
     * blocking version of set()
     * @see {@link set}
     */
    setSync(key, value) { return deasyncPromise(this.set(key, value)); }
    /**
     * set a key/value to etcd.
     * * a `Buffer` is saved as-is
     * * `null` is saved as an empty string
     * * `undefined` is saved as an empty string
     * * strings are saved as-is
     * * everthing else is tried to `JSON.stringify(value)`
     * @param key - etcd key to set
     * @param value - content to set
     * @return `true`
     */
    set(key, value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.callClient("KV", "put", {
                key: this.getBuffer(key),
                value: this.getBuffer(value)
            }).then((res) => {
                return true;
            });
        });
    }
}
exports.Etcd = Etcd;

==> node-etcd3-0.2.0.tgz: package/index.js <==
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator.throw(value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
const grpc = require("grpc");
const deasyncPromise = require("deasync-promise");
const etcdProto = grpc.load(__dirname + "/protos/rpc.proto");
class EtcdError extends Error {
    constructor(message, internal) {
        super(message);
        this.internal = internal;
    }
}
class Etcd {
    constructor(servers = ["localhost:2379"], options = {}) {
        this.credentials = grpc.credentials.createInsecure();
        this.servers = servers;
        if (this.servers.length > 1)
            console.warn("etcd3: currently only the first server address is used");
        this.options = options;
        this.clients = {
            KV: new etcdProto.etcdserverpb.KV(this.servers[0], this.credentials)
        };
    }
    getBuffer(obj) {
        if (Buffer.isBuffer(obj))
            return obj;
        else if (obj == null)
            return new Buffer(0);
        else if (typeof obj === "string")
            return new Buffer(obj);
        else
            return new Buffer(JSON.stringify(obj));
    }
    callClient(client, method, arg) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                this.clients[client][method](arg, (err, response) => {
                    if (err) {
                        reject(new EtcdError(`etcd ${client}.${method} failed`, err));
                        return;
                    }
                    resolve(response);
                });
            });
        });
    }
    /**
     * blocking version of get()
     * @see {@link get}
     */
    getSync(key) {
        return deasyncPromise(this.get(key));
    }
    /**
     * get a key from etcd
     * @param key - key to get
     * @return value of the key
     */
    get(key) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.callClient("KV", "range", {
                key: new Buffer(key)
            }).then((res) => {
                if (res.kvs.length) {
                    return res.kvs[0].value.toString();
                }
                else {
                    // key not found
                    return null;
                }
            });
        });
    }
    /**
     * blocking version of range()
     * @see {@link range}
     */
    rangeSync(fromKey, toKey) {
        return deasyncPromise(this.range(fromKey, toKey));
    }
    /**
     * get a range of key from etcd
     * @param fromKey - key to start from
     * @param toKey - key to end on
     * @return value of the key
     */
    range(fromKey, toKey) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.callClient("KV", "range", {
                key: new Buffer(fromKey),
                range_end: new Buffer(toKey),
                limit: 500
            }).then((res) => {
                let result = {};
                for (let kv of res.kvs) {
                    result[kv.key.toString()] = kv.value.toString();
                }
                return result;
            });
        });
    }
    /**
     * blocking version of set()
     * @see {@link set}
     */
    setSync(key, value) {
        return deasyncPromise(this.set(key, value));
    }
    /**
     * set a key/value to etcd.
     * * a `Buffer` is saved as-is
     * * `null` is saved as an empty string
     * * `undefined` is saved as an empty string
     * * strings are saved as-is
     * * everthing else is tried to `JSON.stringify(value)`
     * @param key - etcd key to set
     * @param value - content to set
     * @return `true`
     */
    set(key, value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.callClient("KV", "put", {
                key: new Buffer(key),
                value: this.getBuffer(value)
            }).then((res) => {
                return true;
            });
        });
    }
    /**
     * blocking version of delete()
     * @see {@link delete}
     */
    deleteSync(key, keyTo) {
        return deasyncPromise(this.delete(key, keyTo));
    }
    /**
     * delete a key from etcd.
     * @param key - etcd key to delete
     * @return number of keys deleted
     */
    delete(key, keyTo) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.callClient("KV", "deleteRange", {
                key: new Buffer(key),
                range_end: keyTo ? new Buffer(keyTo) : null
            }).then((res) => {
                return res.deleted;
            });
        });
    }
}
exports.Etcd = Etcd;
